import { NestFactory } from '@nestjs/core';
import { SampleAppModule } from './sample-app.module';
import { MicroserviceOptions, Transport } from '@nestjs/microservices';
import 'dotenv/config'

async function bootstrap() {
  // This example contains a hybrid application (HTTP + TCP + Socket)
  const host: string = process.env.HOST as unknown as string
  const restPort: number = process.env.SAMPLEAPP_REST_PORT as unknown as number
  const tcpPort: number = process.env.SAMPLEAPP_TCP_PORT as unknown as number

  const app = await NestFactory.create(SampleAppModule);
  app.connectMicroservice<MicroserviceOptions>({
    transport: Transport.TCP,
    options: {
      host: host,
      port: tcpPort,
      retryAttempts: 5,
      retryDelay: 3000
    },
  });

  await app.startAllMicroservices();
  await app.listen(restPort, host);
  console.log(`REST API is running on: ${await app.getUrl()} and TCP is running on ${host}:${tcpPort}`);
}
bootstrap();
